@@ -59,11 +59,6 @@ def setup_create_parser(subparsers):
         'create', help='command for creating trend stores'
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition'
-    )
-
     cmd.add_argument(
         '--create-partitions', default=False, action='store_true',
         help='create partitions according to retention configuration'
@@ -77,21 +72,6 @@ def setup_create_parser(subparsers):
     cmd.set_defaults(cmd=create_trend_store_cmd)
 
 
-def load_definition(in_file: BinaryIO, file_format: str) -> dict:
-    """
-    Load definition data in one of the supported formats (YAML, JSON)
-    :param in_file: Path of the file to load
-    :param file_format: Format of the data
-    :return: dict
-    """
-    if file_format == 'json':
-        return json.load(in_file)
-    elif file_format == 'yaml':
-        return yaml.load(in_file, Loader=yaml.SafeLoader)
-    else:
-        raise ConfigurationError('Unsupported format: {format}')
-
-
 def create_trend_store_cmd(args):
     trend_store = MinervaInstance.load_trend_store_from_file(args.definition)
 
@@ -118,11 +98,6 @@ def setup_add_trends_parser(subparsers):
         'add-trends', help='command for adding trends to trend stores'
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition'
-    )
-
     cmd.add_argument(
         'definition', type=argparse.FileType('r'),
         help='file containing trend store definition'
@@ -132,7 +107,9 @@ def setup_add_trends_parser(subparsers):
 
 
 def add_trends_cmd(args):
-    trend_store = load_trend_store(args.definition, args.format)
+    instance = MinervaInstance.load()
+
+    trend_store = instance.load_trend_store_from_file(args.definition)
 
     try:
         result = add_trends_to_trend_store(trend_store)
@@ -151,11 +128,6 @@ def setup_add_parts_parser(subparsers):
         'add-parts', help='command for adding parts to trend stores'
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition (default is yaml)'
-    )
-
     cmd.add_argument(
         'definition', type=argparse.FileType('r'),
         help='file containing trend store definition'
@@ -164,22 +136,11 @@ def setup_add_parts_parser(subparsers):
     cmd.set_defaults(cmd=add_parts_cmd)
 
 
-def load_trend_store(in_file: BinaryIO, file_format: str) -> TrendStore:
-    trend_store_def = load_definition(in_file, file_format)
-
-    return TrendStore.from_dict(trend_store_def)
-
-
 def setup_remove_parser(subparsers):
     cmd = subparsers.add_parser(
         'remove-trends', help='command for removing trends from trend stores'
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition'
-    )
-
     cmd.add_argument(
         'definition', type=argparse.FileType('r'),
         help='file containing trend store definition'
@@ -189,10 +150,12 @@ def setup_remove_parser(subparsers):
 
 
 def remove_trends_cmd(args):
-    trend_store_definition = load_trend_store(args.definition, args.format)
+    instance = MinervaInstance.load()
+
+    trend_store = instance.load_trend_store_from_file(args.definition)
 
     try:
-        result = remove_trends_from_trend_store(trend_store_definition)
+        result = remove_trends_from_trend_store(trend_store)
         if result:
             sys.stdout.write(f"Removed trends: {result}\n")
         else:
@@ -215,11 +178,6 @@ def setup_alter_trends_parser(subparsers):
 
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition'
-    )
-
     cmd.add_argument(
         'definition', type=argparse.FileType('r'),
         help='file containing trend store definition'
@@ -229,11 +187,12 @@ def setup_alter_trends_parser(subparsers):
 
 
 def alter_trends_cmd(args):
-    trend_store_config = load_definition(args.definition, args.format)
+    instance = MinervaInstance.load()
+    trend_store = instance.load_trend_store_from_file(args.definition)
 
     try:
-        result = alter_tables_in_trend_store_from_json(
-            trend_store_config, force=args.force
+        result = alter_tables_in_trend_store(
+            trend_store, force=args.force
         )
 
         if result:
@@ -255,11 +214,6 @@ def setup_change_trends_parser(subparsers):
         help='change datatype even if the new datatype is less powerful than the old one'  # noqa: disable=E501
     )
 
-    cmd.add_argument(
-        '--format', choices=['yaml', 'json'], default='yaml',
-        help='format of definition'
-    )
-
     cmd.add_argument(
         'definition', type=argparse.FileType('r'),
         help='file containing trend store definition'
@@ -269,7 +223,9 @@ def setup_change_trends_parser(subparsers):
 
 
 def change_trends_cmd(args):
-    trend_store = load_trend_store(args.definition, args.format)
+    instance = MinervaInstance.load()
+
+    trend_store = instance.load_trend_store_from_file(args.definition)
 
     try:
         result = change_trend_store(trend_store, force=args.force)
@@ -293,7 +249,9 @@ def change_trends_cmd(args):
 
 
 def add_parts_cmd(args):
-    trend_store = load_trend_store(args.definition, args.format)
+    instance = MinervaInstance.load()
+
+    trend_store = instance.load_trend_store_from_file(args.definition)
 
     sys.stdout.write(
         "Adding trend store parts to trend store '{}' - '{}' - '{}' ... \n".format(  # noqa: disable=E501
@@ -438,7 +396,7 @@ def add_trends_to_trend_store(trend_store_definition: TrendStore):
     return ', '.join(str(r) for r in result[0])
 
 
-def remove_trends_from_trend_store(trend_store_definition: TrendStore):
+def remove_trends_from_trend_store(trend_store: TrendStore):
     query = (
         'SELECT trend_directory.remove_extra_trends('
         'trend_directory.get_trend_store('
@@ -448,10 +406,10 @@ def remove_trends_from_trend_store(trend_store_definition: TrendStore):
     )
 
     query_args = (
-        trend_store_definition.data_source,
-        trend_store_definition.entity_type,
-        trend_store_definition.granularity,
-        trend_store_definition.parts
+        trend_store.data_source,
+        trend_store.entity_type,
+        trend_store.granularity,
+        trend_store.parts
     )
 
     with closing(connect()) as conn:
@@ -467,7 +425,7 @@ def remove_trends_from_trend_store(trend_store_definition: TrendStore):
         return None
 
 
-def alter_tables_in_trend_store_from_json(trend_store_definition: TrendStore, force=False):
+def alter_tables_in_trend_store(trend_store: TrendStore, force=False):
     query = (
         'SELECT trend_directory.{}('
         'trend_directory.get_trend_store('
@@ -480,10 +438,10 @@ def alter_tables_in_trend_store_from_json(trend_store_definition: TrendStore, fo
     )
 
     query_args = (
-        trend_store_definition.data_source,
-        trend_store_definition.entity_type,
-        trend_store_definition.granularity,
-        trend_store_definition.parts
+        trend_store.data_source,
+        trend_store.entity_type,
+        trend_store.granularity,
+        trend_store.parts
     )
 
     with closing(connect()) as conn:
@@ -805,46 +763,51 @@ def remove_old_partitions_cmd(args):
 
     removed_partitions = 0
 
-    with connect() as conn:
-        with conn.cursor() as cursor:
-            cursor.execute(partition_count_query)
-            total_partitions, = cursor.fetchone()
+    try:
+        with connect() as conn:
+            with conn.cursor() as cursor:
+                cursor.execute(partition_count_query)
+                total_partitions, = cursor.fetchone()
 
-            cursor.execute(old_partitions_query)
+                cursor.execute(old_partitions_query)
 
-            rows = cursor.fetchall()
+                rows = cursor.fetchall()
 
-            print(f'Found {len(rows)} of {total_partitions} partitions to be removed')
+                print(f'Found {len(rows)} of {total_partitions} partitions to be removed')
 
-            conn.commit()
+                conn.commit()
 
-            if len(rows) > 0:
-                print()
-
-                for partition_id, partition_name, data_from, data_to in rows:
-                    if not args.pretend:
-                        cursor.execute(f'drop table trend_partition."{partition_name}"')
-                        cursor.execute('delete from trend_directory.partition where id = %s', (partition_id,))
-                        conn.commit()
-                    removed_partitions += 1
-                    print(f' - {partition_name} ({data_from} - {data_to})')
-
-                if args.pretend:
-                    print(f'\nWould have removed {removed_partitions} of {total_partitions} partitions')
-                else:
-                    print(f'\nRemoved {removed_partitions} of {total_partitions} partitions')
+                if len(rows) > 0:
+                    print()
+                    for partition_id, partition_name, data_from, data_to in rows:
+                        if not args.pretend:
+                            cursor.execute(f'drop table trend_partition."{partition_name}"')
+                            cursor.execute('delete from trend_directory.partition where id = %s', (partition_id,))
+                            conn.commit()
+                            removed_partitions += 1
+                            print(f' - {partition_name} ({data_from} - {data_to})')
+                            
+                    if args.pretend:
+                        print(f'\nWould have removed {removed_partitions} of {total_partitions} partitions')
+                    else:
+                        print(f'\nRemoved {removed_partitions} of {total_partitions} partitions')
+    except psycopg2.errors.LockNotAvailable as partition_lock:
+        print(f"Could not remove partitions: {partition_lock}")
 
 
 def create_partition_cmd(args):
     ahead_interval = args.ahead_interval or '1 day'
 
-    with closing(connect()) as conn:
-        if args.trend_store is None:
-            create_partitions_for_all_trend_stores(conn, ahead_interval)
-        else:
-            create_partitions_for_one_trend_store(
-                conn, args.trend_store, ahead_interval
-            )
+    try:
+        with closing(connect()) as conn:
+            if args.trend_store is None:
+                create_partitions_for_all_trend_stores(conn, ahead_interval)
+            else:
+                create_partitions_for_one_trend_store(
+                    conn, args.trend_store, ahead_interval
+                )
+    except psycopg2.errors.LockNotAvailable as partition_lock:
+        print(f"Could not create partition: {partition_lock}")
 
 
 def create_partitions_for_one_trend_store(conn, trend_store_id, ahead_interval):
@@ -988,6 +951,38 @@ def materialize_cmd(args):
         raise exc
 
 
+class MaterializationChunk:
+    materialization_id: int
+    name: str
+    timestamp: datetime.datetime
+
+    def __init__(self, materialization_id: int, name: str, timestamp: datetime.datetime):
+        self.materialization_id = materialization_id
+        self.name = name
+        self.timestamp = timestamp
+
+    def materialize(self, conn):
+        try:
+            materialize_query = (
+                "SELECT (trend_directory.materialize(m, %s)).row_count "
+                "FROM trend_directory.materialization m WHERE id = %s"
+            )
+
+            with conn.cursor() as cursor:
+                cursor.execute(materialize_query, (self.timestamp, self.materialization_id))
+                row_count, = cursor.fetchone()
+
+            conn.commit()
+
+            print("{} - {}: {} records".format(self.name, self.timestamp, row_count))
+        except Exception as e:
+            conn.rollback()
+            print("Error materializing {} ({})".format(
+                self.name, self.materialization_id
+            ))
+            print(str(e))
+
+
 def get_materialization_chunks_to_run(conn, materialization, reset: bool, max_num: Optional[int], newest_first: bool):
     args = []
 
@@ -1048,27 +1043,17 @@ def get_materialization_chunks_to_run(conn, materialization, reset: bool, max_nu
 
     conn.commit()
 
-    return rows
+    return [MaterializationChunk(*row) for row in rows]
 
 
-def materialize_selection(materializations, reset: bool, max_num: Optional[int]):
+def materialize_selection(materializations, reset: bool, max_num: Optional[int], newest_first: bool):
     with closing(connect()) as conn:
         for materialization in materializations:
-            rows = get_materialization_chunks_to_run(conn, materialization, reset, max_num)
+            chunks = get_materialization_chunks_to_run(conn, materialization, reset, max_num, newest_first)
 
-            for materialization_id, name, timestamp in rows:
-                try:
-                    row_count = materialize(conn, materialization_id, timestamp)
-
-                    conn.commit()
-
-                    print("{} - {}: {} records".format(name, timestamp, row_count))
-                except Exception as e:
-                    conn.rollback()
-                    print("Error materializing {} ({})".format(
-                        name, materialization_id
-                    ))
-                    print(str(e))
+            for chunk in chunks:
+                chunk.materialize(conn)
+                conn.commit()
 
 
 def is_max_modified_supported(conn) -> bool:
@@ -1145,33 +1130,11 @@ def materialize_all(reset: bool, max_num: Optional[int], newest_first: bool):
         with closing(conn.cursor()) as cursor:
             cursor.execute(query, args)
 
-            rows = cursor.fetchall()
+            chunks = [MaterializationChunk(*row) for row in cursor.fetchall()]
 
         conn.commit()
 
-        for materialization_id, name, timestamp in rows:
-            try:
-                row_count = materialize(conn, materialization_id, timestamp)
+        for chunk in chunks:
+            chunk.materialize(conn)
 
-                conn.commit()
-
-                print("{} - {}: {} records".format(name, timestamp, row_count))
-            except Exception as e:
-                conn.rollback()
-                print("Error materializing {} ({})".format(
-                    name, materialization_id
-                ))
-                print(str(e))
-
-
-def materialize(conn, materialization_id, timestamp):
-    materialize_query = (
-        "SELECT (trend_directory.materialize(m, %s)).row_count "
-        "FROM trend_directory.materialization m WHERE id = %s"
-    )
-
-    with closing(conn.cursor()) as cursor:
-        cursor.execute(materialize_query, (timestamp, materialization_id))
-        row_count, = cursor.fetchone()
-
-    return row_count
+            conn.commit()
