@@ -1,3 +1,4 @@
+import json
 import os
 from io import TextIOBase
 from typing import List, Generator, Union, Tuple, Optional
@@ -36,15 +37,6 @@ ENTITY_AGGREGATION_TYPE_MAP_REVERSE = {
 }
 
 
-class AggregationHint:
-    relation: str
-    aggregation_type: EntityAggregationType
-
-    def __init__(self, relation, aggregation_type: EntityAggregationType):
-        self.relation = relation
-        self.aggregation_type = aggregation_type
-
-
 class Trend:
     def __init__(self, name, data_type, description, time_aggregation, entity_aggregation, extra_data):
         self.name = name
@@ -349,6 +341,47 @@ class AttributeStore:
 
         return OrderedDict(items)
 
+class NotificationStore:
+    title: Optional[str]
+    data_source: str
+    entity_type: str
+    attributes: List[Attribute]
+
+    def __init__(self, data_source, entity_type, attributes):
+        self.title = None
+        self.data_source = data_source
+        self.entity_type = entity_type
+        self.attributes = attributes
+
+    def __str__(self):
+        return f'{self.data_source}_{self.entity_type}'
+
+    @staticmethod
+    def from_dict(data: dict):
+        notification_store = NotificationStore(
+            data['data_source'],
+            data['entity_type'],
+            [Attribute.from_dict(a) for a in data['attributes']]
+        )
+
+        notification_store.title = data.get('title')
+
+        return notification_store
+
+    def to_dict(self) -> OrderedDict:
+        items = []
+
+        if self.title:
+            items.append(('title', self.title))
+
+        items.extend([
+            ('data_source', self.data_source),
+            ('entity_type', self.entity_type),
+            ('attributes', [attribute.to_dict() for attribute in self.attributes]),
+        ])
+
+        return OrderedDict(items)
+    
 
 class Relation:
     name: str
@@ -439,7 +472,7 @@ class MinervaInstance:
             hints_data = yaml.load(hints_file, Loader=yaml.SafeLoader)
 
         return {
-            relation_name: AggregationHint(relation_name, ENTITY_AGGREGATION_TYPE_MAP[aggregation_type])
+            relation_name: ENTITY_AGGREGATION_TYPE_MAP[aggregation_type]
             for relation_name, aggregation_type in hints_data.items()
         }
 
@@ -453,13 +486,7 @@ class MinervaInstance:
         """
         Load and return trend store from the provided path
         """
-        if isinstance(file, Path):
-            with file.open() as definition_file:
-                definition = yaml.load(definition_file, Loader=yaml.SafeLoader)
-        elif isinstance(file, TextIOBase):
-            definition = yaml.load(file, Loader=yaml.SafeLoader)
-        else:
-            raise Exception('Unsupported argument type for file')
+        definition = load_yaml(file)
 
         return TrendStore.from_dict(definition)
 
@@ -487,16 +514,16 @@ class MinervaInstance:
 
     @staticmethod
     def load_attribute_store_from_file(file: Union[Path, TextIOBase]) -> AttributeStore:
-        if isinstance(file, Path):
-            with file.open() as definition_file:
-                definition = yaml.load(definition_file, Loader=yaml.SafeLoader)
-        elif isinstance(file, TextIOBase):
-            definition = yaml.load(file, Loader=yaml.SafeLoader)
-        else:
-            raise Exception('Unsupported argument type for file')
+        definition = load_yaml(file)
 
         return AttributeStore.from_dict(definition)
 
+    @staticmethod
+    def load_notification_store_from_file(file: Union[Path, TextIOBase]) -> NotificationStore:
+        definition = load_yaml(file)
+
+        return NotificationStore.from_dict(definition)  
+
     def list_trend_stores(self) -> List[Path]:
         """
         Return list of trend store file paths in the instance trend directory
@@ -552,11 +579,10 @@ class MinervaInstance:
         return self.load_relation_from_file(yaml_file_path)
 
     @staticmethod
-    def load_relation_from_file(yaml_file_path: Path):
-        with yaml_file_path.open() as yaml_file:
-            definition = yaml.load(yaml_file, Loader=yaml.SafeLoader)
+    def load_relation_from_file(yaml_file: Union[Path, TextIOBase]):
+        definition = load_yaml(yaml_file)
 
-            return Relation.from_dict(definition)
+        return Relation.from_dict(definition)
 
     def load_relations(self) -> Generator[Relation, None, None]:
         """
@@ -567,3 +593,27 @@ class MinervaInstance:
             self.load_relation_from_file(path)
             for path in self.list_relations()
         )
+
+
+def load_yaml(file: Union[Path, TextIOBase]) -> Union[list, dict]:
+    if isinstance(file, Path):
+        with file.open() as definition_file:
+            data = yaml.load(definition_file, Loader=yaml.SafeLoader)
+    elif isinstance(file, TextIOBase):
+        data = yaml.load(file, Loader=yaml.SafeLoader)
+    else:
+        raise ValueError('Unsupported argument type for file')
+
+    return data
+
+
+def load_json(file: Union[Path, TextIOBase]) -> Union[list, dict]:
+    if isinstance(file, Path):
+        with file.open() as definition_file:
+            data = json.load(definition_file)
+    elif isinstance(file, TextIOBase):
+        data = json.load(file)
+    else:
+        raise ValueError('Unsupported argument type for file')
+
+    return data
